==> qore-xml-module-1.8.1.tar.bz2: qore-xml-module-1.8.1/docs/xml/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore XML Module", "index.html", [
    [ "Introduction", "index.html#xmlintro", null ],
    [ "Module Option Constants", "index.html#optionconstants", null ],
    [ "Automatic XML Serialization and Deserialization", "index.html#serialization", [
      [ "Serializing and Deserializing XML Attributes", "index.html#xmlattributeserialization", null ],
      [ "Serializing and Deserializing XML Arrays", "index.html#xmlarrayserialization", null ],
      [ "Serializing and Deserializing XML Comments", "index.html#xmlcommentserialization", null ],
      [ "Serializing and Deserializing XML CDATA", "index.html#xmlcdataserialization", null ]
    ] ],
    [ "XML-RPC", "index.html#XMLRPC", null ],
    [ "XML Constants", "index.html#constants", null ],
    [ "Function and Method Tags", "index.html#codetags", [
      [ "NOOP", "index.html#NOOP", null ],
      [ "RUNTIME_NOOP", "index.html#RUNTIME_NOOP", null ],
      [ "RET_VALUE_ONLY", "index.html#RET_VALUE_ONLY", null ],
      [ "CONSTANT", "index.html#CONSTANT", null ],
      [ "DEPRECATED", "index.html#DEPRECATED", null ]
    ] ],
    [ "Release Notes", "index.html#xmlreleasenotes", [
      [ "xml Module Version 1.6.1", "index.html#xml161", null ],
      [ "xml Module Version 1.6", "index.html#xml16", null ],
      [ "xml Module Version 1.5.3", "index.html#xml153", null ],
      [ "xml Module Version 1.5.2", "index.html#xml152", null ],
      [ "xml Module Version 1.5.1", "index.html#xml151", null ],
      [ "xml Module Version 1.5", "index.html#xml15", null ],
      [ "xml Module Version 1.4.2", "index.html#xml142", null ],
      [ "xml Module Version 1.4.1", "index.html#xml141", null ],
      [ "xml Module Version 1.4", "index.html#xml14", null ],
      [ "xml Module Version 1.3.2", "index.html#xml132", null ],
      [ "xml Module Version 1.3.1", "index.html#xml131", null ],
      [ "xml Module Version 1.3", "index.html#xml13", null ],
      [ "xml Module Version 1.2", "index.html#xml12", null ],
      [ "xml Module Version 1.1", "index.html#xml11", null ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__xml__functions.html#gaf9992355e68589537fd988a2b9a57852"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-xml-module-2.0.0.tar.bz2: qore-xml-module-2.0.0/docs/xml/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore XML Module", "index.html", [
    [ "Introduction", "index.html#xmlintro", null ],
    [ "Module Option Constants", "index.html#optionconstants", null ],
    [ "Automatic XML Serialization and Deserialization", "index.html#serialization", [
      [ "Serializing and Deserializing XML Attributes", "index.html#xmlattributeserialization", null ],
      [ "Serializing and Deserializing XML Arrays", "index.html#xmlarrayserialization", null ],
      [ "Serializing and Deserializing XML Comments", "index.html#xmlcommentserialization", null ],
      [ "Serializing and Deserializing XML CDATA", "index.html#xmlcdataserialization", null ]
    ] ],
    [ "XML-RPC", "index.html#XMLRPC", null ],
    [ "XML Constants", "index.html#constants", null ],
    [ "Function and Method Tags", "index.html#codetags", [
      [ "NOOP", "index.html#NOOP", null ],
      [ "RUNTIME_NOOP", "index.html#RUNTIME_NOOP", null ],
      [ "RET_VALUE_ONLY", "index.html#RET_VALUE_ONLY", null ],
      [ "CONSTANT", "index.html#CONSTANT", null ],
      [ "DEPRECATED", "index.html#DEPRECATED", null ]
    ] ],
    [ "Release Notes", "index.html#xmlreleasenotes", [
      [ "xml Module Version 2.0.0", "index.html#xml200", null ],
      [ "xml Module Version 1.8.1", "index.html#xml181", null ],
      [ "xml Module Version 1.8.0", "index.html#xml180", null ],
      [ "xml Module Version 1.7.1", "index.html#xml171", null ],
      [ "xml Module Version 1.7.0", "index.html#xml17", null ],
      [ "xml Module Version 1.6.1", "index.html#xml161", null ],
      [ "xml Module Version 1.6", "index.html#xml16", null ],
      [ "xml Module Version 1.5.3", "index.html#xml153", null ],
      [ "xml Module Version 1.5.2", "index.html#xml152", null ],
      [ "xml Module Version 1.5.1", "index.html#xml151", null ],
      [ "xml Module Version 1.5", "index.html#xml15", null ],
      [ "xml Module Version 1.4.2", "index.html#xml142", null ],
      [ "xml Module Version 1.4.1", "index.html#xml141", null ],
      [ "xml Module Version 1.4", "index.html#xml14", null ],
      [ "xml Module Version 1.3.2", "index.html#xml132", null ],
      [ "xml Module Version 1.3.1", "index.html#xml131", null ],
      [ "xml Module Version 1.3", "index.html#xml13", null ],
      [ "xml Module Version 1.2", "index.html#xml12", null ],
      [ "xml Module Version 1.1", "index.html#xml11", null ]
    ] ],
    [ "XML Generation Options", "xml_generation_opts.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Topics", "topics.html", "topics" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__XmlNodeTypes.html#ga06aefca1bd1a71c2ff20ceba5773dbe3"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
